@@ -55,6 +55,9 @@ class MinutesFormFieldTest(TestCase):
         minutes = 480
         for i in range(60):
             self.assertEqual(minutes + i, f.clean('8:%d' % (i)))
+        # No errors on empty value when the field is not required
+        f.required = False
+        f.clean(None)
 
     def test_minutes_field_invalid(self):
         f = MinutesFormField()
@@ -79,6 +82,7 @@ class MinutesWidgetTest(TestCase):
         tpl = '<input type="text" name="hi" value="%s" />'
         self.assertEqual(w.render('hi', '121'), tpl % '2:01')
         self.assertEqual(w.render('hi', '2:1'), tpl % '2:1')
+        self.assertEqual(w.render('hi', 60), tpl % '1:00')
         self.assertEqual(w.render('hi', '2:60'), tpl % '2:60')
         self.assertEqual(w.render('hi', '493'), tpl % '8:13')
 
